#!/bin/bash
# packager: Rémi Descard <remed> remi~DOT~descard~AT~gmail~DOT~com
# source: http://quodlibet.googlecode.com/files/quodlibet-plugins-2.2.1.tar.gz

softname=quodlibet-plugins
softversion=2.2.1
zenver=64
pkgver=1

arch=i486 
cpu=i686

prefix=/usr

# log
(

# parameters
buildir=$(pwd)
srcpkg=$buildir/$(ls $softname-$softversion.*)
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$zenver.$pkgver"
dest="$buildir/$package"

# prepare the build directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# slack-desc file
cat << EOF > $dest/install/slack-desc
      		 |-------handy-ruler---------------------------------------------------|
quodlibet-plugins: quodlibet (Audio library tagger, manager, and player for GTK+)
quodlibet-plugins: 
quodlibet-plugins: Quod Libet is a GTK+-based audio player written in Python, using the
quodlibet-plugins: Mutagen  tagging library. It's designed around the idea that you 
quodlibet-plugins: know how to organize your music better than we do.
quodlibet-plugins: 
EOF

# extract the source code
# assuming everything has been tar-ed before compression

cd $buildir
srcext=$(echo $srcpkg | rev | cut -d . -f 1 | rev) 
case $srcext in
       'gz' | 'tgz' )
       compression=gzip
       ;;
       'bz2' | 'tbz' )
       compression=bzip2
       ;;
       'xz' | 'txz' )
       compression=xz
       ;;
       'lzma' | 'tlz' )
       compression=lzma
       ;;
esac
$compression -dc $srcpkg | tar xf -

# no real build here
# find which python version is installed
pyversion=$( cd /usr/bin && ls python?.?)

# create target directory
plugindir=$dest/usr/lib/$pyversion/site-packages/quodlibet/plugins
mkdir -p $plugindir

# move files
cd $src
mv \
	README \
	$dest/usr/doc/$softname-$softversion

cp -ra * $plugindir

# compress man pages, if any 
if [ -d $dest/usr/man ] ; then 
	gzip -9 $dest/usr/man/man?/*
fi

# strip 
( cd $dest
 find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
 find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# copy buildfile
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion/

# set target permissions 
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# create package
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# clean
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
